@@ -1,4 +1,4 @@
-/*  Copyright (C) 2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,8 +11,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+
 /*!
  * \file
  *
@@ -61,6 +62,8 @@ enum {
 	/*! \brief Default EDNS alignment size for a response. */
 	KNOT_EDNS_ALIGNMENT_RESPONSE_DEFAULT = 468,
 
+	/*! \brief Current EDNS cookie version. */
+	KNOT_EDNS_COOKIE_VERSION       = 1,
 	/*! \brief EDNS client cookie size. */
 	KNOT_EDNS_COOKIE_CLNT_SIZE     = 8,
 	/*! \brief EDNS minimum server cookie size. */
@@ -303,13 +306,16 @@ int knot_edns_add_option(knot_rrset_t *opt_rr, uint16_t code,
 /*!
  * \brief Searches the OPT RR for option with the specified code.
  *
- * \param opt_rr  OPT RR structure to search in.
- * \param code    Option code to search for.
+ * \param opt_rr    OPT RR structure to search in.
+ * \param code      Option code to search for.
+ * \param previous  (Optional) Previously returned option to start searching from,
+ *                  to be able to return another option with the same code.
  *
  * \retval pointer to option if found
  * \retval NULL otherwise.
  */
-uint8_t *knot_edns_get_option(const knot_rrset_t *opt_rr, uint16_t code);
+uint8_t *knot_edns_get_option(const knot_rrset_t *opt_rr, uint16_t code,
+                              const uint8_t *previous);
 
 /*!
  * \brief Pointers to every option in the OPT RR wire.
